# Generated by Django 5.0.3 on 2024-03-25 02:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('translator', '0021_alter_claudetranslator_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='geminitranslator',
            name='model',
            field=models.CharField(choices=[('gemini-pro', 'gemini-pro'), ('gemini-1.5-pro', 'gemini-1.5-pro')], default='gemini-pro', max_length=100),
        ),
    ]
