# Generated by Django 5.0.1 on 2024-01-26 15:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0003_azureaitranslator_openaitranslator_frequency_penalty_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openaitranslator',
            name='model',
            field=models.CharField(
                choices=[('gpt-3.5-turbo', 'gpt-3.5-turbo'), ('gpt-3.5-turbo-16k', 'gpt-3.5-turbo-16k'),
                         ('gpt-4', 'gpt-4'), ('gpt-4-32k', 'gpt-4-32k')], default='gpt-3.5-turbo', max_length=100),
        ),
    ]
