# Generated by Django 5.0.3 on 2024-03-21 00:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0020_moonshotaitranslator"),
    ]

    operations = [
        migrations.AlterField(
            model_name="claudetranslator",
            name="model",
            field=models.CharField(
                choices=[
                    ("claude-3-haiku-20240307", "claude-3-haiku-20240307"),
                    ("claude-3-sonnet-20240229", "claude-3-sonnet-20240229"),
                    ("claude-3-opus-20240229", "claude-3-opus-20240229"),
                ],
                default="claude-instant-1.2",
                max_length=50,
            ),
        ),
    ]
